@@ -199,7 +199,8 @@ typedef struct _MHW_VEBOX_3D_LUT
     uint32_t    ArbitrationPriorityControl                  : 2;
     uint32_t    Lut3dEnable                                 : 1;
     uint32_t    Lut3dSize                                   : 2;
-    uint32_t                                                : 27; // Reserved
+    uint32_t    ChannelMappingSwapForLut3D                  : 1;
+    uint32_t                                                : 26; // Reserved
 } MHW_VEBOX_3D_LUT, *PMHW_VEBOX_3D_LUT;
 
 //!
@@ -298,6 +299,8 @@ typedef struct _MHW_VEBOX_DNDI_PARAMS
     uint32_t  MemSizeInBytes        = 0;
     bool      bEnableSlimIPUDenoise = false;
 
+    // FDFB
+    bool      dndistateforFDFB      = false;
 } MHW_VEBOX_DNDI_PARAMS, *PMHW_VEBOX_DNDI_PARAMS;
 
 //!
@@ -623,6 +626,9 @@ typedef struct _MHW_VEBOX_IECP_PARAMS
     float                           *pfFeCscCoeff;                              // [3x3] Front End CSC Coeff matrix
     float                           *pfFeCscInOffset;                           // [3x1] Front End CSC Input Offset matrix
     float                           *pfFeCscOutOffset;                          // [3x1] Front End CSC Output Offset matrix
+
+    // FDFB
+    bool                            iecpstateforFDFB;
 } MHW_VEBOX_IECP_PARAMS, *PMHW_VEBOX_IECP_PARAMS;
 
 //!
@@ -692,6 +698,9 @@ typedef struct _MHW_VEBOX_GAMUT_PARAMS
     // HDR
     bool                                bH2S;
     uint16_t                            uiMaxCLL;
+
+    // FDFB
+    bool                                gamutstateforFDFB;
 } MHW_VEBOX_GAMUT_PARAMS, *PMHW_VEBOX_GAMUT_PARAMS;
 
 //!
