@@ -27,12 +27,14 @@
 //!
 #include "vphal.h"
 #include "mos_os.h"
+#include "mos_interface.h"
 #include "mhw_vebox.h"
 #include "renderhal.h"
 #include "vphal_renderer.h"
 #include "mos_solo_generic.h"
 #include "media_interfaces_vphal.h"
 #include "media_interfaces_mhw.h"
+#include "mhw_vebox_itf.h"
 
 //!
 //! \brief    Allocate VPHAL Resources
@@ -51,11 +53,53 @@ MOS_STATUS VphalState::Allocate(
     RENDERHAL_SETTINGS          RenderHalSettings;
     MOS_GPU_NODE                VeboxGpuNode;
     MOS_GPU_CONTEXT             VeboxGpuContext;
+    bool                        checkGpuCtxOverwriten = false;
+    bool                        addGpuCtxToCheckList  = false;
     MOS_STATUS                  eStatus;
 
     VPHAL_PUBLIC_CHK_NULL(pVpHalSettings);
     VPHAL_PUBLIC_CHK_NULL(m_renderHal);
 
+    m_clearVideoViewMode = pVpHalSettings->clearVideoViewMode;
+
+    if ((MEDIA_IS_SKU(m_skuTable, FtrVERing) ||
+         MEDIA_IS_SKU(m_skuTable, FtrSFCPipe)) &&
+        !m_clearVideoViewMode)
+    {
+        MhwInterfaces *             mhwInterfaces = nullptr;
+        MhwInterfaces::CreateParams params;
+        MOS_ZeroMemory(&params, sizeof(params));
+        params.Flags.m_sfc   = MEDIA_IS_SKU(m_skuTable, FtrSFCPipe);
+        params.Flags.m_vebox = MEDIA_IS_SKU(m_skuTable, FtrVERing);
+
+        mhwInterfaces = MhwInterfaces::CreateFactory(params, m_osInterface);
+        if (mhwInterfaces)
+        {
+            SetMhwVeboxInterface(mhwInterfaces->m_veboxInterface);
+            SetMhwSfcInterface(mhwInterfaces->m_sfcInterface);
+
+            // MhwInterfaces always create CP and MI interfaces, so we have to delete those we don't need.
+            MOS_Delete(mhwInterfaces->m_miInterface);
+            Delete_MhwCpInterface(mhwInterfaces->m_cpInterface);
+            mhwInterfaces->m_cpInterface = nullptr;
+            MOS_Delete(mhwInterfaces);
+        }
+        else
+        {
+            VPHAL_DEBUG_ASSERTMESSAGE("Allocate MhwInterfaces failed");
+            eStatus = MOS_STATUS_NO_SPACE;
+            MT_ERR1(MT_VP_HAL_INIT, MT_CODE_LINE, __LINE__);
+        }
+    }
+
+    if (IsApoEnabled() &&
+        m_osInterface->apoMosEnabled &&
+        m_osInterface->bSetHandleInvalid)
+    {
+        checkGpuCtxOverwriten = true;
+    }
+    addGpuCtxToCheckList = checkGpuCtxOverwriten && !IsGpuContextReused(m_renderGpuContext);
+
     // Create Render GPU Context
     {
         MOS_GPUCTX_CREATOPTIONS createOption;
@@ -71,27 +115,59 @@ MOS_STATUS VphalState::Allocate(
         m_osInterface,
         m_renderGpuContext));
 
+    // Add gpu context entry, including stream 0 gpu contexts
+    // In legacy path, stream 0 gpu contexts could be reused, and will keep these stream 0 gpu contexts alive
+    // But its mapping relation could be overwritten in APO path
+    // Now, don't reuse these stream 0 gpu contexts overwritten by MediaContext in APO path 
+    // Can not add reused GPU context
+    if (addGpuCtxToCheckList)
+    {
+        AddGpuContextToCheckList(m_renderGpuContext);
+    }
+
     // Register Render GPU context with the event
     VPHAL_PUBLIC_CHK_STATUS(m_osInterface->pfnRegisterBBCompleteNotifyEvent(
         m_osInterface,
         m_renderGpuContext));
 
-    if (MEDIA_IS_SKU(m_skuTable, FtrVERing) && m_veboxInterface)
+    if (MEDIA_IS_SKU(m_skuTable, FtrVERing) && m_veboxInterface && !m_clearVideoViewMode)
     {
         GpuNodeLimit.bSfcInUse         = MEDIA_IS_SKU(m_skuTable, FtrSFCPipe);
 
+        if (m_veboxItf)
+        {
+            // Check GPU Node decide logic together in this function
+            VPHAL_HW_CHK_STATUS(m_veboxItf->FindVeboxGpuNodeToUse(&GpuNodeLimit));
+
+            VeboxGpuNode    = (MOS_GPU_NODE)(GpuNodeLimit.dwGpuNodeToUse);
+            VeboxGpuContext = (VeboxGpuNode == MOS_GPU_NODE_VE) ? MOS_GPU_CONTEXT_VEBOX : MOS_GPU_CONTEXT_VEBOX2;
+
+            VPHAL_PUBLIC_CHK_STATUS(m_veboxItf->CreateGpuContext(
+                m_osInterface,
+                VeboxGpuContext,
+                VeboxGpuNode));
+        }
+
         // Check GPU Node decide logic together in this function
         VPHAL_HW_CHK_STATUS(m_veboxInterface->FindVeboxGpuNodeToUse(&GpuNodeLimit));
 
         VeboxGpuNode    = (MOS_GPU_NODE)(GpuNodeLimit.dwGpuNodeToUse);
         VeboxGpuContext = (VeboxGpuNode == MOS_GPU_NODE_VE) ? MOS_GPU_CONTEXT_VEBOX : MOS_GPU_CONTEXT_VEBOX2;
 
+        addGpuCtxToCheckList = checkGpuCtxOverwriten && !IsGpuContextReused(VeboxGpuContext);
+      
         // Create VEBOX/VEBOX2 Context
         VPHAL_PUBLIC_CHK_STATUS(m_veboxInterface->CreateGpuContext(
             m_osInterface,
             VeboxGpuContext,
             VeboxGpuNode));
 
+        // Add gpu context entry, including stream 0 gpu contexts
+        if (addGpuCtxToCheckList)
+        {
+            AddGpuContextToCheckList(VeboxGpuContext);
+        }
+        
         // Register Vebox GPU context with the Batch Buffer completion event
         // Ignore if creation fails
         VPHAL_PUBLIC_CHK_STATUS(m_osInterface->pfnRegisterBBCompleteNotifyEvent(
@@ -103,12 +179,28 @@ MOS_STATUS VphalState::Allocate(
     RenderHalSettings.iMediaStates  = pVpHalSettings->mediaStates;
     VPHAL_PUBLIC_CHK_STATUS(m_renderHal->pfnInitialize(m_renderHal, &RenderHalSettings));
 
-    if (m_veboxInterface &&
-        m_veboxInterface->m_veboxSettings.uiNumInstances > 0 &&
-        m_veboxInterface->m_veboxHeap == nullptr)
+    if (!m_clearVideoViewMode)
     {
-        // Allocate VEBOX Heap
-        VPHAL_PUBLIC_CHK_STATUS(m_veboxInterface->CreateHeap());
+        if (m_veboxItf)
+        {
+            const MHW_VEBOX_HEAP *veboxHeap = nullptr;
+            m_veboxItf->GetVeboxHeapInfo(&veboxHeap);
+            uint32_t uiNumInstances = m_veboxItf->GetVeboxNumInstances();
+
+            if (uiNumInstances > 0 &&
+                veboxHeap == nullptr)
+            {
+                // Allocate VEBOX Heap
+                VPHAL_PUBLIC_CHK_STATUS(m_veboxItf->CreateHeap());
+            }
+        }
+
+        if (m_veboxInterface &&
+            m_veboxInterface->m_veboxSettings.uiNumInstances > 0 &&
+            m_veboxInterface->m_veboxHeap == nullptr)
+        {
+            VPHAL_PUBLIC_CHK_STATUS(m_veboxInterface->CreateHeap());
+        }
     }
 
     // Create renderer
@@ -415,6 +507,7 @@ static MOS_STATUS VpHal_RenderWithAvsForMultiStreams(
                 eStatus             = eStatusSingleRender;
                 bHasNonAvsSubstream = false;
                 VPHAL_PUBLIC_ASSERTMESSAGE("Failed to create intermediate surface, eStatus: %d.\n", eStatus);
+                MT_ERR1(MT_VP_HAL_REALLOC_SURF, MT_CODE_LINE, __LINE__);
             }
         }
     } 
@@ -471,6 +564,7 @@ static MOS_STATUS VpHal_RenderWithAvsForMultiStreams(
             {
                 eStatus = eStatusSingleRender;
                 VPHAL_PUBLIC_ASSERTMESSAGE("Failed to redner for primary streams, eStatus: %d.\n", eStatus);
+                MT_ERR2(MT_VP_HAL_RENDER, MT_ERROR_CODE, eStatus, MT_CODE_LINE, __LINE__);
             }
         }
     }
@@ -505,6 +599,7 @@ static MOS_STATUS VpHal_RenderWithAvsForMultiStreams(
         {
             eStatus = eStatusSingleRender;
             VPHAL_PUBLIC_ASSERTMESSAGE("Failed to redner for substreams, eStatus: %d.\n", eStatus);
+            MT_ERR2(MT_VP_HAL_RENDER, MT_ERROR_CODE, eStatus, MT_CODE_LINE, __LINE__);
         }
 
         //Free the temporary surface
@@ -583,7 +678,6 @@ VphalState::VphalState(
         PMOS_INTERFACE          pOsInterface,
         PMOS_CONTEXT            pOsDriverContext,
         MOS_STATUS              *peStatus) :
-        m_gpuAppTaskEvent(nullptr),
         m_platform(),
         m_skuTable(nullptr),
         m_waTable(nullptr),
@@ -607,6 +701,9 @@ VphalState::VphalState(
     m_skuTable = m_osInterface->pfnGetSkuTable(m_osInterface);
     m_waTable  = m_osInterface->pfnGetWaTable (m_osInterface);
 
+    m_userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
+    VpUtils::DeclareUserSettings(m_userSettingPtr);
+
     m_renderHal = (PRENDERHAL_INTERFACE)MOS_AllocAndZeroMemory(sizeof(*m_renderHal));
     VPHAL_PUBLIC_CHK_NULL(m_renderHal);
     VPHAL_PUBLIC_CHK_STATUS(RenderHal_InitInterface(
@@ -614,34 +711,6 @@ VphalState::VphalState(
         &m_cpInterface,
         m_osInterface));
 
-    if (MEDIA_IS_SKU(m_skuTable, FtrVERing) ||
-        MEDIA_IS_SKU(m_skuTable, FtrSFCPipe))
-    {
-        MhwInterfaces *mhwInterfaces = nullptr;
-        MhwInterfaces::CreateParams params;
-        MOS_ZeroMemory(&params, sizeof(params));
-        params.Flags.m_sfc   = MEDIA_IS_SKU(m_skuTable, FtrSFCPipe);
-        params.Flags.m_vebox = MEDIA_IS_SKU(m_skuTable, FtrVERing);
-
-        mhwInterfaces = MhwInterfaces::CreateFactory(params, pOsInterface);
-        if (mhwInterfaces)
-        {
-            SetMhwVeboxInterface(mhwInterfaces->m_veboxInterface);
-            SetMhwSfcInterface(mhwInterfaces->m_sfcInterface);
-
-            // MhwInterfaces always create CP and MI interfaces, so we have to delete those we don't need.
-            MOS_Delete(mhwInterfaces->m_miInterface);
-            Delete_MhwCpInterface(mhwInterfaces->m_cpInterface);
-            mhwInterfaces->m_cpInterface = nullptr;
-            MOS_Delete(mhwInterfaces);
-        }
-        else
-        {
-            VPHAL_DEBUG_ASSERTMESSAGE("Allocate MhwInterfaces failed");
-            eStatus = MOS_STATUS_NO_SPACE;
-        }
-    }
-
 finish:
     if(peStatus)
     {
@@ -673,6 +742,7 @@ VphalState::~VphalState()
             if (eStatus != MOS_STATUS_SUCCESS)
             {
                 VPHAL_PUBLIC_ASSERTMESSAGE("Failed to destroy RenderHal, eStatus:%d.\n", eStatus);
+                MT_ERR1(MT_VP_HAL_DESTROY, MT_CODE_LINE, __LINE__);
             }
         }
         MOS_FreeMemory(m_renderHal);
@@ -692,12 +762,19 @@ VphalState::~VphalState()
 
     if (m_veboxInterface)
     {
+        if (m_veboxItf)
+        {
+            eStatus = m_veboxItf->DestroyHeap();
+        }
+
         eStatus = m_veboxInterface->DestroyHeap();
         MOS_Delete(m_veboxInterface);
         m_veboxInterface = nullptr;
+        m_veboxItf       = nullptr;
         if (eStatus != MOS_STATUS_SUCCESS)
         {
             VPHAL_PUBLIC_ASSERTMESSAGE("Failed to destroy Vebox Interface, eStatus:%d.\n", eStatus);
+            MT_ERR1(MT_VP_HAL_DESTROY, MT_CODE_LINE, __LINE__);
         }
     }
 
@@ -706,6 +783,13 @@ VphalState::~VphalState()
     {
         if (m_osInterface->bDeallocateOnExit)
         {
+            //Clear some overwriten gpucontext resources
+            if (!m_gpuContextCheckList.empty())
+            {
+                DestroyGpuContextWithInvalidHandle();
+                m_gpuContextCheckList.clear();
+            }
+            
             m_osInterface->pfnDestroy(m_osInterface, true);
 
             // Deallocate OS interface structure (except if externally provided)
@@ -785,11 +869,7 @@ MOS_STATUS VphalState::GetStatusReport(
             continue;
         }
 
-#if (LINUX || ANDROID)
-        dwGpuTag           = pOsContext->GetGPUTag(m_osInterface, pStatusEntry->GpuContextOrdinal);
-#else
-        dwGpuTag           = pOsContext->GetGPUTag(pOsContext->GetGpuContextHandle(pStatusEntry->GpuContextOrdinal, m_osInterface->streamIndex));
-#endif
+        dwGpuTag           = m_osInterface->pfnGetGpuStatusSyncTag(m_osInterface, pStatusEntry->GpuContextOrdinal);
         bDoneByGpu         = (dwGpuTag >= pStatusEntry->dwTag);
         bFailedOnSubmitCmd = (pStatusEntry->dwStatus == VPREP_ERROR);
 
@@ -897,3 +977,111 @@ MOS_STATUS VphalState::GetVpMhwInterface(
 
     return eStatus;
 }
+
+//!
+//! \brief    Put GPU context entry
+//! \details  Put GPU context entry in the m_gpuContextCheckList
+//! \param    MOS_GPU_CONTEXT mosGpuConext
+//!           [in] Mos GPU context
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS VphalState::AddGpuContextToCheckList(
+    MOS_GPU_CONTEXT mosGpuConext) 
+{
+#if !EMUL 
+    MOS_GPU_CONTEXT originalGpuCtxOrdinal = m_osInterface->CurrentGpuContextOrdinal;
+    if (mosGpuConext != originalGpuCtxOrdinal)
+    {
+        // Set GPU context temporarily
+        VPHAL_PUBLIC_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(
+            m_osInterface,
+            mosGpuConext));
+    }
+    VPHAL_GPU_CONTEXT_ENTRY tmpEntry;
+    tmpEntry.gpuCtxForMos     = mosGpuConext;
+    tmpEntry.gpuContextHandle = m_osInterface->CurrentGpuContextHandle;
+    tmpEntry.pGpuContext      = m_osInterface->pfnGetGpuContextbyHandle(m_osInterface, m_osInterface->CurrentGpuContextHandle);
+    m_gpuContextCheckList.push_back(tmpEntry);
+
+    if (mosGpuConext != originalGpuCtxOrdinal)
+    {
+        //Recover original settings
+        VPHAL_PUBLIC_CHK_STATUS_RETURN(m_osInterface->pfnSetGpuContext(
+            m_osInterface,
+            originalGpuCtxOrdinal));
+    }
+#endif
+
+    return MOS_STATUS_SUCCESS;
+}
+
+//!
+//! \brief    Destroy GPU context entry with invalid handle
+//! \details  Release these GPU context overwritten by MediaContext
+//! \return   MOS_STATUS
+//!           Return MOS_STATUS_SUCCESS if successful, otherwise failed
+//!
+MOS_STATUS VphalState::DestroyGpuContextWithInvalidHandle() 
+{
+#if !EMUL
+    MOS_GPU_CONTEXT originalGpuCtxOrdinal = m_osInterface->CurrentGpuContextOrdinal;
+    for (auto &curGpuEntry : m_gpuContextCheckList)
+    {
+        //Failure in switching GPU Context indicates that we can't find and release gpu context in normal flow later
+        //So if failed to switch GPU Context, just need to check GPU context, and release it here
+        //If switch GPU Context successfully, need to check both handle and GPU context
+        if ((MOS_FAILED(m_osInterface->pfnSetGpuContext(m_osInterface, curGpuEntry.gpuCtxForMos)) || 
+            m_osInterface->CurrentGpuContextHandle != curGpuEntry.gpuContextHandle) &&
+            m_osInterface->pfnGetGpuContextbyHandle(m_osInterface, curGpuEntry.gpuContextHandle) == curGpuEntry.pGpuContext)
+        {
+            MosInterface::WaitForCmdCompletion(m_osInterface->osStreamState, curGpuEntry.gpuContextHandle);
+
+            MosInterface::DestroyGpuContext(m_osInterface->osStreamState, curGpuEntry.gpuContextHandle);
+        }
+    }
+    if (m_osInterface->CurrentGpuContextOrdinal != originalGpuCtxOrdinal)
+    {
+        //Recover original settings
+        if (m_osInterface->pfnSetGpuContext(m_osInterface, originalGpuCtxOrdinal) != MOS_STATUS_SUCCESS)
+        {
+            VPHAL_PUBLIC_NORMALMESSAGE("Have not recovered original GPU Context settings in m_osInterface");
+        }
+    }
+#endif
+
+    return MOS_STATUS_SUCCESS;
+}
+
+//!
+//! \brief    Check whether GPU context is reused or not
+//! \details  Check whether GPU context is reused or not
+//! \param    MOS_GPU_CONTEXT mosGpuConext
+//!           [in] Mos GPU context
+//! \return   bool
+//!           Return true if is reused, otherwise false
+//!
+bool VphalState::IsGpuContextReused(
+    MOS_GPU_CONTEXT mosGpuContext)
+{
+    bool reuseContextFlag = false;
+#if !EMUL
+    MOS_GPU_CONTEXT originalGpuCtxOrdinal = m_osInterface->CurrentGpuContextOrdinal;
+    if (MOS_SUCCEEDED(m_osInterface->pfnSetGpuContext(m_osInterface, mosGpuContext)))
+    {
+        VPHAL_PUBLIC_NORMALMESSAGE("Reuse mos GPU context %d. GPU handle %d", (uint32_t)mosGpuContext, m_osInterface->CurrentGpuContextHandle);
+        reuseContextFlag = true;
+    }
+
+    if (originalGpuCtxOrdinal < MOS_GPU_CONTEXT_MAX &&
+        m_osInterface->CurrentGpuContextOrdinal != originalGpuCtxOrdinal)
+    {
+        //Recover original settings
+        if (m_osInterface->pfnSetGpuContext(m_osInterface, originalGpuCtxOrdinal) != MOS_STATUS_SUCCESS)
+        {
+            VPHAL_PUBLIC_NORMALMESSAGE("Have not recovered original GPU Context settings in m_osInterface");
+        }
+    }
+#endif
+    return reuseContextFlag;
+}
\ No newline at end of file
