@@ -171,6 +171,10 @@ VphalSfcState::VphalSfcState(
     m_renderHal       = renderHal;
     m_sfcInterface    = sfcInterface;
     m_osInterface     = osInterface;
+    if (m_osInterface)
+    {
+        m_userSettingPtr = m_osInterface->pfnGetUserSettingInstance(m_osInterface);
+    }
 
     // Allocate AVS state
     VpHal_RndrCommonInitAVSParams(
@@ -284,6 +288,62 @@ finish:
     return;
 }
 
+bool VphalSfcState::IsSFCUncompressedWriteNeeded(
+    PVPHAL_SURFACE pRenderTarget)
+{
+    if (!pRenderTarget)
+    {
+        return false;
+    }
+
+    if (!MEDIA_IS_SKU(m_renderHal->pSkuTable, FtrE2ECompression))
+    {
+        return false;
+    }
+
+    uint32_t byteInpixel = 1;
+#if !EMUL
+    if (!pRenderTarget->OsResource.pGmmResInfo)
+    {
+        VPHAL_RENDER_NORMALMESSAGE("IsSFCUncompressedWriteNeeded cannot support non GMM info cases");
+        return false;
+    }
+
+    byteInpixel = pRenderTarget->OsResource.pGmmResInfo->GetBitsPerPixel() >> 3;
+#endif // !EMUL
+
+    if (byteInpixel == 0)
+    {
+        VPHAL_RENDER_NORMALMESSAGE("surface format is not a valid format for sfc");
+        return false;
+    }
+    uint32_t writeAlignInWidth  = 32 / byteInpixel;
+    uint32_t writeAlignInHeight = 8;
+
+    if ((pRenderTarget->rcSrc.top % writeAlignInHeight) ||
+        ((pRenderTarget->rcSrc.bottom - pRenderTarget->rcSrc.top) % writeAlignInHeight) ||
+        (pRenderTarget->rcSrc.left % writeAlignInWidth) ||
+        ((pRenderTarget->rcSrc.right - pRenderTarget->rcSrc.left) % writeAlignInWidth))
+    {
+        VPHAL_RENDER_NORMALMESSAGE(
+            "SFC Render Target Uncompressed write needed, \
+            pRenderTarget->rcSrc.top % d, \
+            pRenderTarget->rcSrc.bottom % d, \
+            pRenderTarget->rcSrc.left % d, \
+            pRenderTarget->rcSrc.right % d \
+            pRenderTarget->Format % d",
+            pRenderTarget->rcSrc.top,
+            pRenderTarget->rcSrc.bottom,
+            pRenderTarget->rcSrc.left,
+            pRenderTarget->rcSrc.right,
+            pRenderTarget->Format);
+
+        return true;
+    }
+
+    return false;
+}
+
 bool VphalSfcState::IsOutputPipeSfcFeasible(
     PCVPHAL_RENDER_PARAMS       pcRenderParams,
     PVPHAL_SURFACE              pSrcSurface,
@@ -505,6 +565,28 @@ VPHAL_OUTPUT_PIPE_MODE VphalSfcState::GetOutputPipe(
         OutputPipe = VPHAL_OUTPUT_PIPE_MODE_COMP;
     }
 
+    if (OutputPipe == VPHAL_OUTPUT_PIPE_MODE_SFC)
+    {
+        // Decompress resource if surfaces need write from a un-align offset
+        if ((!pRenderTarget->OsResource.bUncompressedWriteNeeded) &&
+            (pRenderTarget->CompressionMode == MOS_MMC_MC)        &&
+            IsSFCUncompressedWriteNeeded(pRenderTarget))
+        {
+            MOS_STATUS eStatus = MOS_STATUS_SUCCESS;
+            eStatus = m_osInterface->pfnDecompResource(m_osInterface, &pRenderTarget->OsResource);
+
+            if (eStatus != MOS_STATUS_SUCCESS)
+            {
+                VPHAL_RENDER_NORMALMESSAGE("inplace decompression failed for sfc target.");
+            }
+            else
+            {
+                VPHAL_RENDER_NORMALMESSAGE("inplace decompression enabled for sfc target RECT is not compression block align.");
+                pRenderTarget->OsResource.bUncompressedWriteNeeded = 1;
+            }
+        }
+    }
+
 finish:
     return OutputPipe;
 }
@@ -869,7 +951,7 @@ MOS_STATUS VphalSfcState::AllocateResources()
         MOS_HW_RESOURCE_DEF_MAX,
         MOS_TILE_UNSET_GMM,
         memTypeSurfVideoMem,
-        MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
+        VPP_INTER_RESOURCE_NOTLOCKABLE));
 
     // Allocate IEF Line Buffer surface----------------------------------------------
     dwWidth  = 1;
@@ -891,7 +973,7 @@ MOS_STATUS VphalSfcState::AllocateResources()
         MOS_HW_RESOURCE_DEF_MAX,
         MOS_TILE_UNSET_GMM,
         memTypeSurfVideoMem,
-        MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
+        VPP_INTER_RESOURCE_NOTLOCKABLE));
 
     // Allocate SFD Line Buffer surface----------------------------------------------
     if (NEED_SFD_LINE_BUFFER(pSfcStateParams->dwScaledRegionHeight))
@@ -913,7 +995,7 @@ MOS_STATUS VphalSfcState::AllocateResources()
             MOS_HW_RESOURCE_DEF_MAX,
             MOS_TILE_UNSET_GMM,
             memTypeSurfVideoMem,
-            MOS_MEMPOOL_DEVICEMEMORY == memTypeSurfVideoMem));
+            VPP_INTER_RESOURCE_NOTLOCKABLE));
     }
 
 finish:
@@ -1190,6 +1272,11 @@ MOS_STATUS VphalSfcState::SetSfcStateParams(
     {
         pSfcStateParams->bBypassXAdaptiveFilter = false;
         pSfcStateParams->bBypassYAdaptiveFilter = false;
+
+        if (MEDIASTATE_SFC_AVS_FILTER_BILINEAR == pSfcStateParams->dwAVSFilterMode)
+        {
+            VPHAL_RENDER_NORMALMESSAGE("Legacy Check: bBypassXAdaptiveFilter/bBypassYAdaptiveFilter are set to false for bilinear scaling.");
+        }
     }
     else
     {
