@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2020-2021, Intel Corporation
+* Copyright (c) 2020-2022, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -29,9 +29,7 @@
 #include "media_libva_util.h"
 #include "media_ddi_encode_const.h"
 #include "codec_def_encode_hevc_g12.h"
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
 #include "codec_def_encode_av1.h"
-#endif
 #include "media_libva_caps_dg2.h"
 #include "media_libva_caps_factory.h"
 #include "media_libva_caps_cp_interface.h"
@@ -41,7 +39,6 @@ extern template class MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>;
 VAStatus MediaLibvaCapsDG2::LoadAv1EncProfileEntrypoints()
 {
     VAStatus status = VA_STATUS_SUCCESS;
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
 #ifdef _AV1_ENCODE_VDENC_SUPPORTED
     AttribMap *attributeList = nullptr;
     if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeAV1Vdenc)||
@@ -51,7 +48,7 @@ VAStatus MediaLibvaCapsDG2::LoadAv1EncProfileEntrypoints()
         DDI_CHK_RET(status, "Failed to initialize Caps!");
         (*attributeList)[VAConfigAttribEncDynamicScaling] = 0;
         (*attributeList)[VAConfigAttribEncTileSupport]    = 1;
-        (*attributeList)[VAConfigAttribEncDirtyRect]      = ENCODE_VDENC_AV1_MAX_DIRTYRECT;
+        (*attributeList)[VAConfigAttribEncDirtyRect]      = 0;
         (*attributeList)[VAConfigAttribEncMaxRefFrames]   = CODEC_AV1_NUM_REFL0P_FRAMES |
             CODEC_AV1_NUM_REFL0B_FRAMES<<8 | CODEC_AV1_NUM_REFL1B_FRAMES<<16;
 
@@ -94,7 +91,6 @@ VAStatus MediaLibvaCapsDG2::LoadAv1EncProfileEntrypoints()
         AddProfileEntry(VAProfileAV1Profile0, VAEntrypointEncSliceLP, attributeList,
                 configStartIdx, m_encConfigs.size() - configStartIdx);
     }
-#endif
 #endif
     return status;
 }
@@ -102,7 +98,7 @@ VAStatus MediaLibvaCapsDG2::LoadAv1EncProfileEntrypoints()
 VAStatus MediaLibvaCapsDG2::LoadAvcEncLpProfileEntrypoints()
 {
     VAStatus status = VA_STATUS_SUCCESS;
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
+
 #if defined(_AVC_ENCODE_VDENC_SUPPORTED)
     AttribMap *attributeList = nullptr;
     if (MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrEncodeAVCVdenc))
@@ -139,7 +135,7 @@ VAStatus MediaLibvaCapsDG2::LoadAvcEncLpProfileEntrypoints()
         }
     }
 #endif
-#endif
+
     return status;
 }
 
@@ -157,7 +153,6 @@ VAStatus MediaLibvaCapsDG2::LoadProfileEntrypoints()
 
 std::string MediaLibvaCapsDG2::GetEncodeCodecKey(VAProfile profile, VAEntrypoint entrypoint, uint32_t feiFunction)
 {
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
     switch (profile)
     {
         case VAProfileH264High:
@@ -182,21 +177,16 @@ std::string MediaLibvaCapsDG2::GetEncodeCodecKey(VAProfile profile, VAEntrypoint
         case VAProfileHEVCMain:
         case VAProfileHEVCMain10:
         case VAProfileHEVCMain12:
-        case VAProfileHEVCMain422_10:
-        case VAProfileHEVCMain422_12:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
         case VAProfileHEVCSccMain:
         case VAProfileHEVCSccMain10:
         case VAProfileHEVCSccMain444:
         case VAProfileHEVCSccMain444_10:
-            if (IsEncFei(entrypoint, feiFunction))
-                return ENCODE_ID_HEVCFEI;
-            else
-                return ENCODE_ID_HEVC;
+            return ENCODE_ID_HEVC;
         case VAProfileAV1Profile0:
         case VAProfileAV1Profile1:
-            return ENCODE_ID_RESERVED0;
+            return ENCODE_ID_AV1;
         case VAProfileNone:
             if (IsEncFei(entrypoint, feiFunction))
                 return ENCODE_ID_AVCFEI;
@@ -205,14 +195,10 @@ std::string MediaLibvaCapsDG2::GetEncodeCodecKey(VAProfile profile, VAEntrypoint
         default:
             return ENCODE_ID_NONE;
     }
-#else
-    return ENCODE_ID_NONE;
-#endif
 }
 
 CODECHAL_MODE MediaLibvaCapsDG2::GetEncodeCodecMode(VAProfile profile, VAEntrypoint entrypoint)
 {
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
     if (entrypoint == VAEntrypointStats)
     {
         return  CODECHAL_ENCODE_MODE_AVC;
@@ -239,8 +225,6 @@ CODECHAL_MODE MediaLibvaCapsDG2::GetEncodeCodecMode(VAProfile profile, VAEntrypo
         case VAProfileHEVCMain:
         case VAProfileHEVCMain10:
         case VAProfileHEVCMain12:
-        case VAProfileHEVCMain422_10:
-        case VAProfileHEVCMain422_12:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
         case VAProfileHEVCSccMain:
@@ -250,14 +234,11 @@ CODECHAL_MODE MediaLibvaCapsDG2::GetEncodeCodecMode(VAProfile profile, VAEntrypo
             return CODECHAL_ENCODE_MODE_HEVC;
         case VAProfileAV1Profile0:
         case VAProfileAV1Profile1:
-            return CODECHAL_ENCODE_RESERVED_0;
+            return CODECHAL_ENCODE_MODE_AV1;
         default:
             DDI_ASSERTMESSAGE("Invalid Encode Mode");
             return CODECHAL_UNSUPPORTED_MODE;
     }
-#else
-    return CODECHAL_UNSUPPORTED_MODE;
-#endif
 }
 
 VAStatus MediaLibvaCapsDG2::CheckEncodeResolution(
@@ -265,7 +246,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncodeResolution(
         uint32_t width,
         uint32_t height)
 {
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
     switch (profile)
     {
         case VAProfileJPEGBaseline:
@@ -292,8 +272,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncodeResolution(
         case VAProfileHEVCMain12:
         case VAProfileHEVCMain444:
         case VAProfileHEVCMain444_10:
-        case VAProfileHEVCMain422_10:
-        case VAProfileHEVCMain422_12:
         case VAProfileHEVCSccMain:
         case VAProfileHEVCSccMain10:
         case VAProfileHEVCSccMain444:
@@ -338,7 +316,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncodeResolution(
             }
             break;
     }
-#endif
     return VA_STATUS_SUCCESS;
 }
 
@@ -348,7 +325,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncRTFormat(
         VAConfigAttrib* attrib)
 {
     DDI_CHK_NULL(attrib, "Null pointer", VA_STATUS_ERROR_INVALID_PARAMETER);
-#ifdef IGFX_DG2_ENABLE_NON_UPSTREAM
     attrib->type = VAConfigAttribRTFormat;
     if (profile == VAProfileJPEGBaseline)
     {
@@ -362,14 +338,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncRTFormat(
     {
         attrib->value = VA_RT_FORMAT_YUV420_12;
     }
-    else if(profile == VAProfileHEVCMain422_10)
-    {
-        attrib->value = VA_RT_FORMAT_YUV422_10;
-    }
-    else if(profile == VAProfileHEVCMain422_12)
-    {
-        attrib->value = VA_RT_FORMAT_YUV422_12;
-    }
     else if(profile == VAProfileHEVCMain444 || profile == VAProfileHEVCSccMain444)
     {
         attrib->value = VA_RT_FORMAT_YUV444;
@@ -401,7 +369,7 @@ VAStatus MediaLibvaCapsDG2::CheckEncRTFormat(
     }
     else if(IsAV1Profile(profile))
     {
-        format = (EncodeFormat)RESERVED0;
+        format = AV1;
     }
 
     for(uint32_t i = 0; i < m_encodeFormatCount && encodeFormatTable != nullptr; encodeFormatTable++, i++)
@@ -413,7 +381,6 @@ VAStatus MediaLibvaCapsDG2::CheckEncRTFormat(
             break;
         }
     }
-#endif
     return VA_STATUS_SUCCESS;
 }
 
@@ -427,23 +394,11 @@ VAStatus MediaLibvaCapsDG2::GetPlatformSpecificAttrib(VAProfile profile,
     *value = VA_ATTRIB_NOT_SUPPORTED;
     switch ((int)type)
     {
-        case VAConfigAttribEncMaxRefFrames:
-        {
-            // just VAConfigAttribEncMaxRefFrames of HEVC VME is different with platforms
-            if (entrypoint == VAEntrypointEncSlice && IsHevcProfile(profile))
-            {
-                *value = ENCODE_DP_HEVC_NUM_MAX_VME_L0_REF_G12 | (ENCODE_DP_HEVC_NUM_MAX_VME_L1_REF_G12 << 16);
-            }
-            else
-            {
-                status = VA_STATUS_ERROR_INVALID_PARAMETER;
-            }
-            break;
-        }
         case VAConfigAttribDecProcessing:
         {
 #ifdef _DECODE_PROCESSING_SUPPORTED
-            if (IsAvcProfile(profile) || IsHevcProfile(profile) || IsJpegProfile(profile) || IsVp9Profile(profile))
+            if ((IsAvcProfile(profile) || IsHevcProfile(profile) || IsJpegProfile(profile) || IsVp9Profile(profile))
+                && !(MEDIA_IS_SKU(&(m_mediaCtx->SkuTable), FtrDisableVDBox2SFC)))
             {
                 *value = VA_DEC_PROCESSING;
             }
@@ -578,7 +533,18 @@ VAStatus MediaLibvaCapsDG2::GetPlatformSpecificAttrib(VAProfile profile,
         }
         case VAConfigAttribPredictionDirection:
         {
-            *value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_FUTURE | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+            if (!IsHevcSccProfile(profile))
+            {
+                *value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_FUTURE | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+            }
+            else
+            {
+                // Here we set
+                // VAConfigAttribPredictionDirection: VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY together with
+                // VAConfigAttribEncMaxRefFrames: L0 != 0, L1 !=0
+                // to indicate SCC only supports I/low delay B
+                *value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+            }
             break;
         }
         default:
@@ -622,17 +588,20 @@ VAStatus MediaLibvaCapsDG2::CreateEncAttributes(
         VAConfigAttribMaxPictureHeight, &attrib.value);
     (*attribList)[attrib.type] = attrib.value;
 
-    attrib.type = VAConfigAttribEncJPEG;
-    attrib.value =
-        ((JPEG_MAX_QUANT_TABLE << 14)       | // max_num_quantization_tables : 3
-         (JPEG_MAX_NUM_HUFF_TABLE_INDEX << 11)   | // max_num_huffman_tables : 3
-         (1 << 7)                    | // max_num_scans : 4
-         (jpegNumComponent << 4));              // max_num_components : 3
-    // arithmatic_coding_mode = 0
-    // progressive_dct_mode = 0
-    // non_interleaved_mode = 0
-    // differential_mode = 0
-    (*attribList)[attrib.type] = attrib.value;
+    if (profile == VAProfileJPEGBaseline)
+    {
+        attrib.type = VAConfigAttribEncJPEG;
+        attrib.value =
+            ((JPEG_MAX_QUANT_TABLE << 14)       | // max_num_quantization_tables : 3
+             (JPEG_MAX_NUM_HUFF_TABLE_INDEX << 11)   | // max_num_huffman_tables : 3
+             (1 << 7)                    | // max_num_scans : 4
+             (jpegNumComponent << 4));              // max_num_components : 3
+        // arithmatic_coding_mode = 0
+        // progressive_dct_mode = 0
+        // non_interleaved_mode = 0
+        // differential_mode = 0
+        (*attribList)[attrib.type] = attrib.value;
+    }
 
     attrib.type = VAConfigAttribEncQualityRange;
     if (profile == VAProfileJPEGBaseline)
@@ -726,7 +695,7 @@ VAStatus MediaLibvaCapsDG2::CreateEncAttributes(
     attrib.type = VAConfigAttribEncInterlaced;
     attrib.value = VA_ENC_INTERLACED_NONE;
 #ifndef ANDROID
-    if(IsAvcProfile(profile))
+    if(IsAvcProfile(profile) && (entrypoint != VAEntrypointEncSliceLP))
     {
         attrib.value = VA_ENC_INTERLACED_FIELD;
     }
@@ -918,15 +887,6 @@ VAStatus MediaLibvaCapsDG2::CreateEncAttributes(
     }
     (*attribList)[attrib.type] = attrib.value;
 
-    if ((entrypoint == VAEntrypointFEI) && (IsAvcProfile(profile) || IsHevcProfile(profile)))
-    {
-        attrib.type = (VAConfigAttribType)VAConfigAttribFEIFunctionType;
-        attrib.value = IsAvcProfile(profile) ?
-                       (VA_FEI_FUNCTION_ENC | VA_FEI_FUNCTION_PAK | VA_FEI_FUNCTION_ENC_PAK) :
-                       VA_FEI_FUNCTION_ENC_PAK;
-        (*attribList)[attrib.type] = attrib.value;
-    }
-
     attrib.type = (VAConfigAttribType)VAConfigAttribFEIMVPredictors;
     attrib.value = 0;
     if(IsAvcProfile(profile) || IsHevcProfile(profile))
@@ -968,7 +928,18 @@ VAStatus MediaLibvaCapsDG2::CreateEncAttributes(
     if (IsHevcProfile(profile))
     {
         attrib.type = (VAConfigAttribType) VAConfigAttribPredictionDirection;
-        attrib.value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_FUTURE | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+        if (!IsHevcSccProfile(profile))
+        {
+            attrib.value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_FUTURE | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+        }
+        else
+        {
+            // Here we set
+            // VAConfigAttribPredictionDirection: VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY together with
+            // VAConfigAttribEncMaxRefFrames: L0 != 0, L1 !=0
+            // to indicate SCC only supports I/low delay B
+            attrib.value = VA_PREDICTION_DIRECTION_PREVIOUS | VA_PREDICTION_DIRECTION_BI_NOT_EMPTY;
+        }
         (*attribList)[attrib.type] = attrib.value;
     }
 
@@ -1029,5 +1000,35 @@ VAStatus MediaLibvaCapsDG2::AddEncSurfaceAttributes(
     return VA_STATUS_SUCCESS;
 }
 
+VAStatus MediaLibvaCapsDG2::GetDisplayAttributes(
+            VADisplayAttribute *attribList,
+            int32_t numAttribs)
+{
+    DDI_CHK_NULL(attribList, "Null attribList", VA_STATUS_ERROR_INVALID_PARAMETER);
+    for(auto i = 0; i < numAttribs; i ++)
+    {
+        switch(attribList->type)
+        {
+            case VADisplayAttribCopy:
+                attribList->min_value = attribList->value = attribList->max_value =
+                    (1 << VA_EXEC_MODE_POWER_SAVING) | (1 << VA_EXEC_MODE_PERFORMANCE) | (1 << VA_EXEC_MODE_DEFAULT);
+                // 100: perfromance model: Render copy
+                // 10:  POWER_SAVING: BLT
+                // 1:   default model: 1: vebox
+                // 0:   don't support media copy.
+                attribList->flags = VA_DISPLAY_ATTRIB_GETTABLE;
+                break;
+            default:
+                attribList->min_value = VA_ATTRIB_NOT_SUPPORTED;
+                attribList->max_value = VA_ATTRIB_NOT_SUPPORTED;
+                attribList->value = VA_ATTRIB_NOT_SUPPORTED;
+                attribList->flags = VA_DISPLAY_ATTRIB_NOT_SUPPORTED;
+                break;
+        }
+        attribList ++;
+    }
+    return VA_STATUS_SUCCESS;
+}
+
 static bool dg2Registered = MediaLibvaCapsFactory<MediaLibvaCaps, DDI_MEDIA_CONTEXT>::
     RegisterCaps<MediaLibvaCapsDG2>((uint32_t)IGFX_DG2);
