@@ -38,7 +38,7 @@ OTHER DEALINGS IN THE SOFTWARE.
 //extern template class DeviceInfoFactory<GfxDeviceInfo>;
 typedef DeviceInfoFactory<GfxDeviceInfo> base_fact;
 
-static bool InitXeHPMediaSysInfo(struct GfxDeviceInfo *devInfo,
+bool InitXeHPMediaSysInfo(struct GfxDeviceInfo *devInfo,
                                 MEDIA_GT_SYSTEM_INFO *sysInfo)
 {
     if ((devInfo == nullptr) || (sysInfo == nullptr))
@@ -83,7 +83,7 @@ static bool InitXeHPMediaSysInfo(struct GfxDeviceInfo *devInfo,
 }
 
 
-static bool InitXeHPShadowSku(struct GfxDeviceInfo *devInfo,
+bool InitXeHPShadowSku(struct GfxDeviceInfo *devInfo,
                              SHADOW_MEDIA_FEATURE_TABLE *skuTable,
                              struct LinuxDriverInfo *drvInfo)
 {
@@ -132,7 +132,7 @@ static bool InitXeHPShadowSku(struct GfxDeviceInfo *devInfo,
     return true;
 }
 
-static bool InitPvcShadowSku(struct GfxDeviceInfo *devInfo,
+bool InitPvcShadowSku(struct GfxDeviceInfo *devInfo,
                              SHADOW_MEDIA_FEATURE_TABLE *skuTable,
                              struct LinuxDriverInfo *drvInfo)
 {
@@ -183,7 +183,7 @@ static bool InitPvcShadowSku(struct GfxDeviceInfo *devInfo,
 }
 
 
-static bool InitXeHPShadowWa(struct GfxDeviceInfo *devInfo,
+bool InitXeHPShadowWa(struct GfxDeviceInfo *devInfo,
                             SHADOW_MEDIA_WA_TABLE *waTable,
                             struct LinuxDriverInfo *drvInfo)
 {
@@ -210,7 +210,7 @@ static bool InitXeHPShadowWa(struct GfxDeviceInfo *devInfo,
     return true;
 }
 
-static bool InitPvcShadowWa(struct GfxDeviceInfo *devInfo,
+bool InitPvcShadowWa(struct GfxDeviceInfo *devInfo,
                             SHADOW_MEDIA_WA_TABLE *waTable,
                             struct LinuxDriverInfo *drvInfo)
 {
@@ -243,6 +243,7 @@ static struct GfxDeviceInfo xehpGt4Info = {
     .productFamily = IGFX_XE_HP_SDV,
     .displayFamily = IGFX_XE_HP_CORE,
     .renderFamily  = IGFX_XE_HP_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT4,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 0,
@@ -263,6 +264,7 @@ static struct GfxDeviceInfo pvcGt4Info = {
     .productFamily = IGFX_PVC,
     .displayFamily = IGFX_GEN12_CORE,
     .renderFamily  = IGFX_XE_HPC_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_GT4,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 0,
@@ -283,6 +285,7 @@ static struct GfxDeviceInfo dg2Gt4Info = {
     .productFamily = IGFX_DG2,
     .displayFamily = IGFX_GEN12_CORE,
     .renderFamily  = IGFX_XE_HPG_CORE,
+    .mediaFamily   = IGFX_UNKNOWN_CORE,
     .eGTType       = GTTYPE_UNDEFINED,
     .L3CacheSizeInKb = 0,
     .L3BankCount   = 0,
