@@ -59,6 +59,35 @@ public:
     {
         return VP_VEBOX_STATISTICS_SIZE_G12;
     }
+    virtual MOS_STATUS ConfigVirtualEngine()
+    {
+        return MOS_STATUS_SUCCESS;    // the config would be set in MhwVeboxInterfaceG12::CreateGpuContext().
+    }
+
+    virtual bool IsEufusionBypassWaEnabled()
+    {
+        return true;
+    }
+
+    virtual bool IsGpuContextCreatedInPipelineInit()
+    {
+        return false;
+    }
+
+    virtual MOS_STATUS GetInputFrameWidthHeightAlignUnit(
+        PVP_MHWINTERFACE          pvpMhwInterface,
+        uint32_t                 &widthAlignUnit,
+        uint32_t                 &heightAlignUnit,
+        bool                      bVdbox,
+        CODECHAL_STANDARD         codecStandard,
+        CodecDecodeJpegChromaType jpegChromaType);
+
+    virtual MOS_STATUS GetVeboxHeapInfo(
+        PVP_MHWINTERFACE          pvpMhwInterface,
+        const MHW_VEBOX_HEAP    **ppVeboxHeap);
+
+    virtual bool IsVeboxScalabilitywith4K(
+        VP_MHWINTERFACE           vpMhwInterface);
 
 protected:
     bool m_disableSfcDithering = false;
