@@ -284,7 +284,7 @@ namespace decode{
         CODECHAL_DEBUG_TOOL(DumpResources(pipeBufAddrParams));
 
 #if MOS_EVENT_TRACE_DUMP_SUPPORTED
-        if (MOS_GetTraceEventKeyword() & EVENT_DECODE_REFYUV_KEYWORD)
+        if (MOS_TraceKeyEnabled(TR_KEY_DECODE_REFYUV))
         {
             TraceDataDumpReferences(pipeBufAddrParams);
         }
@@ -658,12 +658,15 @@ namespace decode{
 
                     ResourceAutoLock resLock(m_allocator, &m_tempRefSurf->OsResource);
                     auto             pData = (uint8_t *)resLock.LockResourceForRead();
-
+                    DECODE_CHK_NULL(pData);
+                    
                     MOS_TraceDataDump(
                         "Decode_AVCRefSurf",
                         n,
                         pData,
                         (uint32_t)m_tempRefSurf->OsResource.pGmmResInfo->GetSizeMainSurface());
+                    
+                    m_allocator->UnLock(&m_tempRefSurf->OsResource);
                 }
             }
         }
