@@ -58,8 +58,8 @@ extern const RENDERHAL_STATE_HEAP_SETTINGS g_cRenderHal_State_Heap_Settings_hpg_
 
     // Surface State Heap Settings
     RENDERHAL_SSH_INSTANCES,                   //!< iSurfaceStateHeaps
-    RENDERHAL_SSH_BINDING_TABLES,              //!< iBindingTables
-    RENDERHAL_SSH_SURFACE_STATES,              //!< iSurfaceStates
+    RENDERHAL_SSH_BINDING_TABLES_MAX,          //!< iBindingTables
+    RENDERHAL_SSH_SURFACE_STATES_MAX,          //!< iSurfaceStates
     RENDERHAL_SSH_SURFACES_PER_BT,             //!< iSurfacesPerBT
     RENDERHAL_SSH_BINDING_TABLE_ALIGN          //!< iBTAlignment
 };
@@ -518,7 +518,6 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::EnableL3Caching(
     MHW_RENDERHAL_CHK_NULL(pRenderHal);
     pMhwRender = pRenderHal->pMhwRenderInterface;
     MHW_RENDERHAL_CHK_NULL(pMhwRender);
-    m_renderItf = std::static_pointer_cast<mhw::render::Itf>(pMhwRender->GetNewRenderInterface());
 
     if (nullptr == pCacheSettings)
     {
@@ -760,31 +759,29 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::SetCompositePrologCmd(
     MHW_RENDERHAL_CHK_NULL(pRenderHal);
     MHW_RENDERHAL_CHK_NULL(pCmdBuffer);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pOsInterface);
-    MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwMiInterface);
-    
+    MHW_RENDERHAL_CHK_NULL(m_miItf);
+
     auxTableBaseAddr = pRenderHal->pOsInterface->pfnGetAuxTableBaseAddr(pRenderHal->pOsInterface);
 
     if (auxTableBaseAddr)
     {
-        MHW_MI_LOAD_REGISTER_IMM_PARAMS lriParams;
-        MOS_ZeroMemory(&lriParams, sizeof(MHW_MI_LOAD_REGISTER_IMM_PARAMS));
+        auto& parImm = m_miItf->MHW_GETPAR_F(MI_LOAD_REGISTER_IMM)();
+        parImm = {};
+        parImm.dwRegister = m_miItf->GetMmioInterfaces(mhw::mi::MHW_MMIO_RCS_AUX_TABLE_BASE_LOW);
+        parImm.dwData = (auxTableBaseAddr & 0xffffffff);
+        m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(pCmdBuffer);
 
-        lriParams.dwRegister = MhwMiInterfaceG12::m_mmioRcsAuxTableBaseLow;
-        lriParams.dwData = (auxTableBaseAddr & 0xffffffff);
-        MHW_RENDERHAL_CHK_STATUS(pRenderHal->pMhwMiInterface->AddMiLoadRegisterImmCmd(pCmdBuffer, &lriParams));
+        parImm.dwRegister = m_miItf->GetMmioInterfaces(mhw::mi::MHW_MMIO_RCS_AUX_TABLE_BASE_HIGH);
+        parImm.dwData = ((auxTableBaseAddr >> 32) & 0xffffffff);
+        m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(pCmdBuffer);
 
-        lriParams.dwRegister = MhwMiInterfaceG12::m_mmioRcsAuxTableBaseHigh;
-        lriParams.dwData = ((auxTableBaseAddr >> 32) & 0xffffffff);
-        MHW_RENDERHAL_CHK_STATUS(pRenderHal->pMhwMiInterface->AddMiLoadRegisterImmCmd(pCmdBuffer, &lriParams));
-
-        lriParams.dwRegister = MhwMiInterfaceG12::m_mmioCcs0AuxTableBaseLow;
-        lriParams.dwData = (auxTableBaseAddr & 0xffffffff);
-        MHW_RENDERHAL_CHK_STATUS(pRenderHal->pMhwMiInterface->AddMiLoadRegisterImmCmd(pCmdBuffer, &lriParams));
-
-        lriParams.dwRegister = MhwMiInterfaceG12::m_mmioCcs0AuxTableBaseHigh;
-        lriParams.dwData = ((auxTableBaseAddr >> 32) & 0xffffffff);
-        MHW_RENDERHAL_CHK_STATUS(pRenderHal->pMhwMiInterface->AddMiLoadRegisterImmCmd(pCmdBuffer, &lriParams));
+        parImm.dwRegister = m_miItf->GetMmioInterfaces(mhw::mi::MHW_MMIO_CCS0_AUX_TABLE_BASE_LOW);
+        parImm.dwData = (auxTableBaseAddr & 0xffffffff);
+        m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(pCmdBuffer);
 
+        parImm.dwRegister = m_miItf->GetMmioInterfaces(mhw::mi::MHW_MMIO_CCS0_AUX_TABLE_BASE_HIGH);
+        parImm.dwData = ((auxTableBaseAddr >> 32) & 0xffffffff);
+        m_miItf->MHW_ADDCMD_F(MI_LOAD_REGISTER_IMM)(pCmdBuffer);
     }
 
 finish:
@@ -804,7 +801,7 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::IsRenderHalMMCEnabled(
     // Read user feature key to set MMC for Fast Composition surfaces
     MOS_ZeroMemory(&UserFeatureData, sizeof(UserFeatureData));
     UserFeatureData.i32DataFlag = MOS_USER_FEATURE_VALUE_DATA_FLAG_CUSTOM_DEFAULT_VALUE_TYPE;
-#ifdef LINUX
+#if defined(LINUX) && (!defined(WDDM_LINUX))
     UserFeatureData.bData = !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableVPMmc) || !MEDIA_IS_WA(pRenderHal->pWaTable, WaDisableCodecMmc);
 #else
     UserFeatureData.bData = true;  // turn on MMC for xe_hpg
@@ -845,7 +842,6 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::SendComputeWalker(
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pStateHeap->pKernelAllocation);
 
-    m_renderItf = std::static_pointer_cast<mhw::render::Itf>(pRenderHal->pMhwRenderInterface->GetNewRenderInterface());
     MOS_ZeroMemory(&mhwIdEntryParams, sizeof(mhwIdEntryParams));
 
     pKernelEntry   = &pRenderHal->pStateHeap->pKernelAllocation[pRenderHal->iKernelAllocationID];
@@ -1170,8 +1166,6 @@ MOS_STATUS XRenderHal_Interface_Xe_Hpg_Base::SendTo3DStateBindingTablePoolAlloc(
     MHW_RENDERHAL_CHK_NULL(pRenderHal);
     MHW_RENDERHAL_CHK_NULL(pCmdBuffer);
     MHW_RENDERHAL_CHK_NULL(pRenderHal->pMhwRenderInterface);
-    m_renderItf = std::static_pointer_cast<mhw::render::Itf>(pRenderHal->pMhwRenderInterface->GetNewRenderInterface());
-
     MHW_RENDERHAL_CHK_NULL(m_renderItf);
     SETPAR_AND_ADDCMD(_3DSTATE_BINDING_TABLE_POOL_ALLOC, m_renderItf, pCmdBuffer);
 
