@@ -49,6 +49,7 @@
 
 #include "mos_defs.h"
 #include "mos_os.h"
+#include "media_class_trace.h"
 
 class GpuContextSpecificNext;
 struct _MOS_VIRTUALENGINE_SET_PARAMS;
@@ -1998,6 +1999,16 @@ public:
     static int GetPlaneSurfaceOffset(
         const MOS_PLANE_OFFSET &planeOffset);
 
+    //!
+    //! \brief    Get Resource array index
+    //! \details  Returns the array index
+    //! \param    PMOS_RESOURCE
+    //!           [in] Pointer to  MOS_RESOURCE
+    //! \return   uint32_t - array index
+    //!
+    static uint32_t GetResourceArrayIndex(
+        PMOS_RESOURCE resource);
+
     //!
     //! \brief  Translate MOS_FORMAT into GMM_RESOURCE_FORMAT
     //!
@@ -2021,6 +2032,17 @@ public:
     //!
     static MediaUserSettingSharedPtr MosGetUserSettingInstance(
         MOS_STREAM_HANDLE streamState);
+
+    //!
+    //! \brief  Translate MOS_OS_FORMT into MOS_FORMAT
+    //!
+    static bool IsCompressibelSurfaceSupported(MEDIA_FEATURE_TABLE *skuTable);
+
+    //!
+    //! \brief  Check if Mismatch Order Programming model is supported
+    //!
+    static bool IsMismatchOrderProgrammingSupported();
+
 private:
     //!
     //! \brief    Init per stream parameters
@@ -2120,6 +2142,7 @@ private:
     static uint32_t m_mosOsApiFailSimulateHint;
     static uint32_t m_mosOsApiFailSimulateCounter;
 #endif
+MEDIA_CLASS_DEFINE_END(MosInterface)
 };
 
 #endif  // __MOS_INTERFACE_H__
