@@ -561,4 +561,264 @@ uint32_t VpUtils::GetSurfaceBitDepth(
 
     VP_PUBLIC_ASSERTMESSAGE("Unknown Input format for bit depth.");
     return 0;
-}
\ No newline at end of file
+}
+
+MOS_STATUS VpUtils::DeclareUserSettings(MediaUserSettingSharedPtr userSettingPtr)
+{
+    DeclareUserSettingKey(  //For debugging purpose. true for disabling SFC
+        userSettingPtr,
+        __VPHAL_VEBOX_DISABLE_SFC,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(  //Disabling SFC DTR output. 1: Disable, 0: Enable
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_DTR_DISABLE,
+        MediaUserSetting::Group::Sequence,
+        1,
+        true);
+
+    DeclareUserSettingKey(  // For Notify which datapath Vebox used
+        userSettingPtr,
+        __VPHAL_VEBOX_OUTPUTPIPE_MODE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(//For Notify which feature Vebox used
+        userSettingPtr,
+        __VPHAL_VEBOX_FEATURE_INUSE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(  //TRUE for Enabling Vebox Scalability. (Default FALSE: disabled")
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VEBOX_SCALABILITY_MODE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey( //Disabling SFC Centering output. 1 -- Disable, 0 -- Enable.
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_SFC_OUTPUT_CENTERING_DISABLE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey( // VP Bypass Composition Mode
+        userSettingPtr,
+        __VPHAL_BYPASS_COMPOSITION,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(  //Enable memory compression
+        userSettingPtr,
+        __VPHAL_ENABLE_MMC,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_VEBOX_TGNE_ENABLE_VP,
+        MediaUserSetting::Group::Sequence,
+        1,
+        true);  // Enable Vebox GNE. 1: Enable, 0: Disable
+
+    DeclareUserSettingKey(//Slice Shutdown Control
+        userSettingPtr,
+        __VPHAL_RNDR_SSD_CONTROL,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKey(  // FALSE if CSC coefficient setting mode is Patch mode, otherwise Curbe mode
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_CSC_COEFF_PATCH_MODE_DISABLE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+#if (_DEBUG || _RELEASE_INTERNAL)
+    DeclareUserSettingKeyForDebug( //Init CP output surface with protected 0.
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_INIT_CP_OUTPUT_SURFACE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // FORCE VP DECOMPRESSED OUTPUT
+        userSettingPtr,
+        __VPHAL_RNDR_FORCE_VP_DECOMPRESSED_OUTPUT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  //Software Scoreboard enable Control
+        userSettingPtr,
+        __VPHAL_RNDR_SCOREBOARD_CONTROL,
+        MediaUserSetting::Group::Sequence,
+        1,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // CM based FC enable Control
+        userSettingPtr,
+        __VPHAL_RNDR_CMFC_CONTROL,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  //Enable 1K 1DLUT
+        userSettingPtr,
+        __VPHAL_ENABLE_1K_1DLUT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __VPHAL_VEBOX_HDR_MODE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true); //"HDR Mode. 0x1: H2S kernel, 0x3: H2H kernel, 0x21 65size H2S, 0x23 65size H2H, 0x31 33size H2S, 0x33 33size H2H."
+
+    DeclareUserSettingKeyForDebug(  // VP Enable Compute Context
+        userSettingPtr,
+        __VPHAL_ENABLE_COMPUTE_CONTEXT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Force VP Memorycopy Outputcompressed
+        userSettingPtr,
+        __VPHAL_VEBOX_FORCE_VP_MEMCOPY_OUTPUTCOMPRESSED,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Composition 8Tap Adaptive Enable
+        userSettingPtr,
+        __VPHAL_COMP_8TAP_ADAPTIVE_ENABLE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Set SFC NV12/P010 Linear Output
+        userSettingPtr,
+        __VPHAL_ENABLE_SFC_NV12_P010_LINEAR_OUTPUT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Set SFC RGBP Linear/Tile RGB24 Linear Output
+        userSettingPtr,
+        __VPHAL_ENABLE_SFC_RGBP_RGB24_OUTPUT,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Surface Dump Outfile
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_OUTFILE_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        "",
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface Dump Location
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_LOCATION_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        "",
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Manual trigger to start VP Surface Dump
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_MANUAL_TRIGGER_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        -1,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface Dump Start Frame
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_START_FRAME_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface Dump End Frame
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_END_FRAME_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        MOS_USER_FEATURE_MAX_UINT32_STR_VALUE,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface dump each plance seprately
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMPER_ENABLE_PLANE_DUMP,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface dump aux data enable
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_ENABLE_AUX_DUMP,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Surface Dump: Locking Resource
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMPER_RESOURCE_LOCK,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP State Dump Enable
+        userSettingPtr,
+        __VPHAL_DBG_STATE_DUMP_ENABLE,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Parameters Dump Outfile
+        userSettingPtr,
+        __VPHAL_DBG_PARAM_DUMP_OUTFILE_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        "",
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Parameters Dump Start Frame
+        userSettingPtr,
+        __VPHAL_DBG_PARAM_DUMP_START_FRAME_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        1,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP Parameters Dump End Frame
+        userSettingPtr,
+        __VPHAL_DBG_PARAM_DUMP_END_FRAME_KEY_NAME,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+    DeclareUserSettingKeyForDebug(  // Vphal Debug Dump Output Directory
+        userSettingPtr,
+        __VPHAL_DBG_DUMP_OUTPUT_DIRECTORY,
+        MediaUserSetting::Group::Sequence,
+        "",
+        true);
+
+    DeclareUserSettingKeyForDebug(  // VP parameter dump sku and wa info enable
+        userSettingPtr,
+        __VPHAL_DBG_PARA_DUMP_ENABLE_SKUWA_DUMP,
+        MediaUserSetting::Group::Sequence,
+        0,
+        true);
+
+#endif
+
+    return MOS_STATUS_SUCCESS;
+}
